@@ -112,7 +112,7 @@ pub fn check_files(
     stdin_path: Option<String>,
     excluded_rules: Option<Vec<String>>,
 ) -> Result<Vec<ViolationContent>, CheckFilesError> {
-    let excluded_rules = excluded_rules.unwrap_or_else(|| vec![]);
+    let excluded_rules = excluded_rules.unwrap_or_else(Vec::new);
 
     let mut output_violations = vec![];
 
@@ -373,6 +373,14 @@ pub fn explain_rule<W: io::Write>(writer: &mut W, name: &str) -> Result<(), std:
     Ok(())
 }
 
+fn get_violations_emoji(count: usize) -> &'static str {
+    if count > 0 {
+        "🚒"
+    } else {
+        "✅"
+    }
+}
+
 fn get_sql_file_content(violation: ViolationContent) -> Result<String, std::io::Error> {
     let sql = violation.sql;
     let mut buff = Vec::new();
@@ -392,27 +400,26 @@ fn get_sql_file_content(violation: ViolationContent) -> Result<String, std::io::
             violations_text.trim_matches('\n')
         )
     } else {
-        "None found.".to_string()
+        "No violations found.".to_string()
     };
 
+    let violations_emoji = get_violations_emoji(violation_count);
+
     Ok(format!(
         r#"
-<details open>
-
-<summary><code>{filename}</code></summary>
+<h3><code>{filename}</code></h3>
 
 ```sql
 {sql}
 ```
 
-### 🚒 Rule Violations ({violation_count})
+<h4>{violations_emoji} Rule Violations ({violation_count})</h4>
 
 {violation_content}
-
-</details>
-
     
+---
     "#,
+        violations_emoji = violations_emoji,
         filename = violation.filename,
         sql = sql,
         violation_count = violation_count,
@@ -422,20 +429,23 @@ fn get_sql_file_content(violation: ViolationContent) -> Result<String, std::io::
 
 pub fn get_comment_body(files: Vec<ViolationContent>) -> String {
     let violations_count: usize = files.iter().map(|x| x.violations.len()).sum();
+
+    let violations_emoji = get_violations_emoji(violations_count);
+
     format!(
         r#"
-# [Squawk](https://github.com/sbdchd/squawk) Report
+# Squawk Report
 
-### **{violation_count}** violations across **{file_count}** file(s)
+### **{violations_emoji} {violation_count}** violations across **{file_count}** file(s)
 
-## 🚛 Source SQL
-{sql_file_content}
 ---
+{sql_file_content}
 
 [📚 More info on rules](https://github.com/sbdchd/squawk#rules)
 
-> ⚡️ Powered by [`Squawk`](https://github.com/sbdchd/squawk)
+⚡️ Powered by [`Squawk`](https://github.com/sbdchd/squawk), a linter for PostgreSQL, focused on migrations
 "#,
+        violations_emoji = violations_emoji,
         violation_count = violations_count,
         file_count = files.len(),
         sql_file_content = files
@@ -484,15 +494,13 @@ SELECT 1;
         let body = get_comment_body(violations);
 
         assert_display_snapshot!(body, @r###"
-# [Squawk](https://github.com/sbdchd/squawk) Report
+# Squawk Report
 
-### **1** violations across **1** file(s)
+### **🚒 1** violations across **1** file(s)
 
-## 🚛 Source SQL
+---
 
-<details open>
-
-<summary><code>alpha.sql</code></summary>
+<h3><code>alpha.sql</code></h3>
 
 ```sql
 
@@ -500,7 +508,7 @@ SELECT 1;
                 
 ```
 
-### 🚒 Rule Violations (1)
+<h4>🚒 Rule Violations (1)</h4>
 
 
 ```
@@ -511,16 +519,13 @@ alpha.sql:1:0: warning: adding-not-nullable-field
   note: Adding a NOT NULL field requires exclusive locks and table rewrites.
   help: Make the field nullable.
 ```
-
-</details>
-
-    
     
 ---
+    
 
 [📚 More info on rules](https://github.com/sbdchd/squawk#rules)
 
-> ⚡️ Powered by [`Squawk`](https://github.com/sbdchd/squawk)
+⚡️ Powered by [`Squawk`](https://github.com/sbdchd/squawk), a linter for PostgreSQL, focused on migrations
 "###);
     }
 
@@ -557,15 +562,13 @@ ALTER TABLE "core_recipe" ADD COLUMN "foo" integer DEFAULT 10;
         let body = get_comment_body(violations);
 
         assert_display_snapshot!(body, @r###"
-# [Squawk](https://github.com/sbdchd/squawk) Report
+# Squawk Report
 
-### **0** violations across **2** file(s)
+### **✅ 0** violations across **2** file(s)
 
-## 🚛 Source SQL
+---
 
-<details open>
-
-<summary><code>alpha.sql</code></summary>
+<h3><code>alpha.sql</code></h3>
 
 ```sql
 
@@ -580,18 +583,14 @@ CREATE TABLE "core_bar" (
                 
 ```
 
-### 🚒 Rule Violations (0)
-
-None found.
-
-</details>
+<h4>✅ Rule Violations (0)</h4>
 
+No violations found.
     
+---
     
 
-<details open>
-
-<summary><code>bravo.sql</code></summary>
+<h3><code>bravo.sql</code></h3>
 
 ```sql
 
@@ -599,20 +598,17 @@ ALTER TABLE "core_recipe" ADD COLUMN "foo" integer DEFAULT 10;
                 
 ```
 
-### 🚒 Rule Violations (0)
+<h4>✅ Rule Violations (0)</h4>
 
-None found.
-
-</details>
-
-    
+No violations found.
     
 ---
+    
 
 [📚 More info on rules](https://github.com/sbdchd/squawk#rules)
 
-> ⚡️ Powered by [`Squawk`](https://github.com/sbdchd/squawk)
-        "###);
+⚡️ Powered by [`Squawk`](https://github.com/sbdchd/squawk), a linter for PostgreSQL, focused on migrations
+"###);
     }
 
     /// Ideally the logic won't leave a comment when there are no migrations but
@@ -624,18 +620,17 @@ None found.
         let body = get_comment_body(violations);
 
         assert_display_snapshot!(body, @r###"
-# [Squawk](https://github.com/sbdchd/squawk) Report
+# Squawk Report
 
-### **0** violations across **0** file(s)
-
-## 🚛 Source SQL
+### **✅ 0** violations across **0** file(s)
 
 ---
 
+
 [📚 More info on rules](https://github.com/sbdchd/squawk#rules)
 
-> ⚡️ Powered by [`Squawk`](https://github.com/sbdchd/squawk)
-        "###);
+⚡️ Powered by [`Squawk`](https://github.com/sbdchd/squawk), a linter for PostgreSQL, focused on migrations
+"###);
     }
 }
 
