@@ -1,7 +1,7 @@
-use crate::github::{comment_on_pr, GithubError, PullRequest};
 use crate::reporter::{check_files, get_comment_body, CheckFilesError};
 use log::info;
 use serde_json::Value;
+use squawk_github::{comment_on_pr, GithubError, PullRequest};
 use structopt::StructOpt;
 
 #[derive(Debug)]
